warn_if_rect_changes_id

Function warn_if_rect_changes_id 

fn warn_if_rect_changes_id(
    out_shapes: &mut Vec<ClippedShape>,
    prev_widgets: &WidgetRects,
    new_widgets: &WidgetRects,
)
Check if any Rect appears with different Ids between two passes.

This helps detect cases where the same screen area is claimed by different widget ids across passes, which is often a sign of id instability.